@@ -1,6 +1,6 @@
 /*
-copyright 2002, 2003 Alexander Malmberg <alexander@malmberg.org>
-forkpty replacement, 2005-2008 Riccardo Mottola <rmottola@users.sf.net>
+copyright 2002-2003 Alexander Malmberg <alexander@malmberg.org>
+          2005-2016 Riccardo Mottola <rmottola@users.sf.net>
 
 This file is a part of Terminal.app. Terminal.app is free software; you
 can redistribute it and/or modify it under the terms of the GNU General
@@ -32,6 +32,7 @@ activated */
 #  include <sys/ioctl.h>
 #  include <termios.h>
 #  include <pcap.h>
+#  include <util.h>
 #define TCSETS TIOCSETA
 #elif defined(__FreeBSD__)
 #  include <sys/types.h>
@@ -58,25 +59,26 @@ activated */
 #endif
 #endif
 
-#include <Foundation/NSBundle.h>
-#include <Foundation/NSDebug.h>
-#include <Foundation/NSNotification.h>
-#include <Foundation/NSRunLoop.h>
-#include <Foundation/NSUserDefaults.h>
-#include <Foundation/NSCharacterSet.h>
-#include <Foundation/NSArchiver.h>
-#include <GNUstepBase/Unicode.h>
-#include <AppKit/NSApplication.h>
-#include <AppKit/NSPasteboard.h>
-#include <AppKit/NSDragging.h>
-#include <AppKit/NSEvent.h>
-#include <AppKit/NSGraphics.h>
-#include <AppKit/NSScroller.h>
-#include <AppKit/DPSOperators.h>
+#import <Foundation/NSBundle.h>
+#import <Foundation/NSDebug.h>
+#import <Foundation/NSNotification.h>
+#import <Foundation/NSRunLoop.h>
+#import <Foundation/NSUserDefaults.h>
+#import <Foundation/NSCharacterSet.h>
+#import <Foundation/NSArchiver.h>
+#import <GNUstepBase/Unicode.h>
+#import <AppKit/NSApplication.h>
+#import <AppKit/NSPasteboard.h>
+#import <AppKit/NSDragging.h>
+#import <AppKit/NSEvent.h>
+#import <AppKit/NSGraphics.h>
+#import <AppKit/NSScroller.h>
+#import <AppKit/DPSOperators.h>
 
-#include "TerminalView.h"
+#import "TerminalView.h"
 
-#include "TerminalViewPrefs.h"
+#import "TerminalViewPrefs.h"
+#import "TerminalParser_Linux.h"
 
 
 /* forkpty replacement */
@@ -85,8 +87,6 @@ activated */
 #include <errno.h> /* for int errno */
 #include <fcntl.h>
 #include <sys/termios.h>
-#include <sys/types.h>
-#include <unistd.h>
 #include <stropts.h>
 #include <stdlib.h>
 #include <string.h>
@@ -473,10 +473,13 @@ if (blackOnWhite)
 	if (pending_scroll)
 		[self _handlePendingScroll: NO];
 
-	/* draw the black border around the view if needed*/
+	/* draw the border around the view if needed */
 	{
 		float a,b;
-		DPSsetgray(cur,0.0);
+		if (blackOnWhite)
+			DPSsetgray(cur,1.0);
+		else
+			DPSsetgray(cur,0.0);
 		if (r.origin.x<border_x)
 			DPSrectfill(cur,r.origin.x,r.origin.y,border_x-r.origin.x,r.size.height);
 		if (r.origin.y<border_y)
@@ -824,13 +827,15 @@ if (blackOnWhite)
 		ASSIGN(title_miniwindow,new_title);
 	if (title_type==2 || title_type==0)
 		ASSIGN(title_window,new_title);
+	if (title_type==3)
+		ASSIGN(title_filename,new_title);
 	[[NSNotificationCenter defaultCenter]
 		postNotificationName: TerminalViewTitleDidChangeNotification
 		object: self];
 }
 
 
--(void) ts_goto: (int)x:(int)y
+-(void) ts_goto: (int)x :(int)y
 {
 	NSDebugLLog(@"ts",@"goto: %i:%i",x,y);
 	cursor_x=x;
@@ -841,7 +846,7 @@ if (blackOnWhite)
 	if (cursor_y<0) cursor_y=0;
 }
 
--(void) ts_putChar: (screen_char_t)ch  count: (int)c  at: (int)x:(int)y
+-(void) ts_putChar: (screen_char_t)ch  count: (int)c  at: (int)x :(int)y
 {
 	int i;
 	screen_char_t *s;
@@ -886,7 +891,7 @@ if (blackOnWhite)
 	ADD_DIRTY(0,0,sx,sy); /* TODO */
 }
 
--(void) ts_scrollUp: (int)t:(int)b  rows: (int)nr  save: (BOOL)save
+-(void) ts_scrollUp: (int)t :(int)b  rows: (int)nr  save: (BOOL)save
 {
 	screen_char_t *d, *s;
 
@@ -972,7 +977,7 @@ if (blackOnWhite)
 	ADD_DIRTY(0,t,sx,b-t);
 }
 
--(void) ts_scrollDown: (int)t:(int)b  rows: (int)nr
+-(void) ts_scrollDown: (int)t :(int)b  rows: (int)nr
 {
 	screen_char_t *s;
 	unsigned int step;
@@ -1078,7 +1083,7 @@ if (blackOnWhite)
 	ADD_DIRTY(0,y,sx,1);
 }
 
--(screen_char_t) ts_getCharAt: (int)x:(int)y
+-(screen_char_t) ts_getCharAt: (int)x :(int)y
 {
 	NSDebugLLog(@"ts",@"getCharAt: %i:%i",x,y);
 	return SCREEN(x,y);
@@ -1130,7 +1135,7 @@ if (blackOnWhite)
 	if (l!=len)
 	{
 		if (errno!=EAGAIN)
-			NSLog(_(@"Unexpected error while writing: %m."));
+			NSLog(_(@"Unexpected error while writing."));
 		if (l<0)
 			l=0;
 		[self addDataToWriteBuffer: &msg[l]  length: len-l];
@@ -1269,8 +1274,8 @@ Keyboard events
 {
 	NSString *s=[e charactersIgnoringModifiers];
 
-	NSDebugLLog(@"key",@"got key flags=%08x  repeat=%i '%@' '%@' %4i %04x %i %04x %i\n",
-		[e modifierFlags],[e isARepeat],[e characters],[e charactersIgnoringModifiers],[e keyCode],
+	NSDebugLLog(@"key",@"got key flags=%08x  repeat=%i '%@' '%@' %4i %04x %li %04x %li\n",
+                    (unsigned int)[e modifierFlags],(int)[e isARepeat],[e characters],[e charactersIgnoringModifiers],[e keyCode],
 		[[e characters] characterAtIndex: 0],[[e characters] length],
 		[[e charactersIgnoringModifiers] characterAtIndex: 0],[[e charactersIgnoringModifiers] length]);
 
@@ -1647,7 +1652,6 @@ Selection, copy/paste/services
 
 	
 	r0.location=r0.length=0;
-	r1=r0;
 	first=YES;
 	ofs0=0; /* get compiler to shut up */
 	g=[e clickCount];
@@ -1860,7 +1864,7 @@ Handle master_fd
 	if (l<0)
 	{
 		if (errno!=EAGAIN)
-			NSLog(_(@"Unexpected error while writing: %m."));
+			NSLog(_(@"Unexpected error while writing."));
 		return;
 	}
 	memmove(write_buf,&write_buf[l],write_buf_len-l);
@@ -1956,7 +1960,7 @@ Handle master_fd
 	{
 		if (pipe(pipefd))
 		{
-			NSLog(_(@"Unable to open pipe for input: %m."));
+			NSLog(_(@"Unable to open pipe for input."));
 			return;
 		}
 		NSDebugLLog(@"pty",@"creating pipe for initial data, got %i %i",
@@ -1968,7 +1972,7 @@ Handle master_fd
 	ret=forkpty(&master_fd,NULL,NULL,&ws);
 	if (ret<0)
 	{
-		NSLog(_(@"Unable to fork: %m."));
+		NSLog(_(@"Unable to fork."));
 		return;
 	}
 
@@ -1996,7 +2000,7 @@ Handle master_fd
 	flags=fcntl(master_fd,F_GETFL,0);
 	if (flags==-1)
 	{
-		NSLog(_(@"Unable to set non-blocking mode: %m."));
+		NSLog(_(@"Unable to set non-blocking mode."));
 	}
 	else
 	{
@@ -2185,8 +2189,12 @@ misc. stuff
 	nsbuf=malloc(nsx*max_scrollback*sizeof(screen_char_t));
 	if (!nscreen || !nsbuf)
 	{
-		NSLog(@"Failed to allocate screen buffer!");
-		return;
+          NSLog(@"Failed to allocate screen buffer!");
+          if (nscreen)
+            free(nscreen);
+          if (nsbuf)
+            free(nsbuf);
+          return;
 	}
 	memset(nscreen,0,sizeof(screen_char_t)*nsx*nsy);
 	memset(nsbuf,0,sizeof(screen_char_t)*nsx*max_scrollback);
@@ -2225,6 +2233,8 @@ improve? */
 	if (sb_length<0)
 		sb_length=0;
 
+        cursor_y = nsy-(sy-cursor_y);
+        
 	sx=nsx;
 	sy=nsy;
 	free(screen);
@@ -2232,9 +2242,8 @@ improve? */
 	screen=nscreen;
 	sbuf=nsbuf;
 
-	if (cursor_x>sx) cursor_x=sx-1;
-	if (cursor_y>sy) cursor_y=sy-1;
-
+        [self ts_goto: cursor_x : cursor_y];
+        
 	[self _updateScroller];
 
 	[tp setTerminalScreenWidth: sx height: sy];
@@ -2360,13 +2369,18 @@ improve? */
 	return title_miniwindow;
 }
 
+-(NSString *) representedFilename
+{
+	return title_filename;
+}
+
 
 -(void) setIgnoreResize: (BOOL)ignore
 {
 	ignore_resize=ignore;
 }
 
--(void) setBorder: (float)x : (float)y
+-(void) setBorder: (CGFloat)x : (CGFloat)y
 {
 	border_x=x;
 	border_y=y;
